/***STATA CODE FOR:
Allen IV, James, "Are Agricultural Markets More Developed Around Cities? Testing
for Urban Heterogeneity in Separability in Tanzania," Food Policy Submission.
Submitted on April 27, 2018 */

*********
* SETUP *
*********
*Merges seven Tanzania LSMS-ISA Wave 4 datasets
*The first "allcrops" includes all farm plots for the primary analysis
*The second "staples" refers to maize & rice plots for the secondary analysis
*Many variables only relevant for full specification available in the appendix

clear all
set more off

foreach dataset in allcrops staples {
**PART 1: Prepare Hh Variables
use TZA_LSMS_2014\hh_sec_b.dta
rename hh_b02 sex
rename hh_b04 age
gen head=1 if hh_b05==1
keep y4_hhid indidy4 sex age head

*demographics that will sum in the collapse
gen hh_all=1
gen hh_child=1 if age<16
gen hh_mprime=1 if sex==1 & age>=16 & age<=55
gen hh_fprime=1 if sex==2 & age>=16 & age<=55
gen hh_melder=1 if sex==1 & age>55
gen hh_felder=1 if sex==2 & age>55
gen age_head=age if head==1

*merge with education data--not doing years of education but dummies for literacy and having attended school
merge 1:1 y4_hhid indidy4 using TZA_LSMS_2014\hh_sec_c.dta
gen literate=1 if hh_c02<5
replace literate=0 if hh_c02==5
recode hh_c03 (2=0), gen(anyschool)
gen literate_head=1 if literate==1 & head==1
gen anyschool_head=1 if anyschool==1 & head==1
gen literate_madult=1 if literate==1 & sex==1 & age>=16
gen anyschool_madult=1 if anyschool==1 & sex==1 & age>=16

*collapse hh characteristics
collapse (sum) hh_all hh_child hh_m* hh_f* age_head liter* anysch*, by(y4_hhid) 

*create demographic fraction variables
gen hhsize=hh_all-hh_child
gen lnhhsize = log(hhsize)
*Fraction for hhsize without children (exclude melder in reg)
gen frac_mprime = hh_mprime / hhsize
gen frac_fprime = hh_fprime / hhsize
gen frac_melder = hh_melder / hhsize
gen frac_felder = hh_felder / hhsize

save hhdata.dta, replace
clear all

**PART 2: Compile Ag Data
*start with plots and area from long rainy season
use TZA_LSMS_2014\ag_sec_2a.dta
keep y4_hhid plotnum ag2a_04 ag2a_07 ag2a_09
rename ag2a_04 acres_rprt
rename ag2a_07 measured
rename ag2a_09 acres_msrd
gen acres=acres_rprt	// total acres overseen by household
replace acres=acres_msrd if measured==1

*merge input data for each plot - perfect merge
merge 1:1 y4_hhid plotnum using TZA_LSMS_2014\ag_sec_3a.dta

*land variables for cultivated plots, which are 92% of all plots in sample.
gen area=acres_rprt if ag3a_03==1	// total area under cultivation
replace area=acres_msrd if measured==1 & ag3a_03==1
gen area_rprt=acres_rprt if ag3a_03==1
gen area_msrd=acres_msrd if ag3a_03==1

*limiting sample to maize and rice plots (staples)
gen allcrops=1
gen staples=1 if ag3a_07_1=="MAHINDI"|ag3a_07_1=="MPUNGA" // Maize & Rice
replace staples=0 if staples==. & ag3a_07_1!=""
keep if `dataset'==1

*household labor (in days)
egen labor_hh_prep = rowtotal(ag3a_72_1 ag3a_72_2 ag3a_72_3 ag3a_72_4 ag3a_72_5 ag3a_72_6)
egen labor_hh_mid = rowtotal(ag3a_72_7 ag3a_72_8 ag3a_72_9 ag3a_72_10 ag3a_72_11 ag3a_72_12)
gen labor_hh_preh = labor_hh_prep + labor_hh_mid
egen labor_hh_harv = rowtotal(ag3a_72_13 ag3a_72_14 ag3a_72_15 ag3a_72_16 ag3a_72_17 ag3a_72_18)
gen labor_hh_ttl = labor_hh_preh + labor_hh_harv

*hired labor (in days)
egen labor_wrk_prep = rowtotal(ag3a_74_1 ag3a_74_2 ag3a_74_3)
egen labor_wrk_mid = rowtotal(ag3a_74_5 ag3a_74_6 ag3a_74_7)
gen labor_wrk_preh = labor_wrk_prep + labor_wrk_mid
egen labor_wrk_harv = rowtotal(ag3a_74_13 ag3a_74_14 ag3a_74_15)
gen labor_wrk_ttl = labor_wrk_preh + labor_wrk_harv
rename ag3a_74_4 ttlpaid_prep
rename ag3a_74_8 ttlpaid_mid
gen ttlpaid_preh = ttlpaid_prep + ttlpaid_mid
rename ag3a_74_16 ttlpaid_harv
gen ttlpaid_ttl = ttlpaid_prep + ttlpaid_mid + ttlpaid_harv

*aggregate labor (in days)
gen labor_preh = labor_hh_preh + labor_wrk_preh
gen labor_harv = labor_hh_harv + labor_wrk_harv
gen labor_ttl = labor_hh_ttl + labor_wrk_ttl

*inputs
gen fert_value = ag3a_51+ag3a_51 
gen fert_qty = ag3a_49+ag3a_56 
gen pest_value = ag3a_65c
gen pest_qty = ag3a_65b_1 if ag3a_65b_2==2	// in litres
replace pest_qty = ag3a_65b_1/1000 if ag3a_65b_2==3	// putting ml in same units

*irrigation: 98% of plots were not irrigated in the long rainy season, so not in regression

*land quality--multiply by cultivated area to collapse
recode ag3a_17 (1=1 "flat") (2=1 "flat")(3=2 "slight") (4=3 "steep"), gen(landslope)  // land slope
tab landslope, gen(landslope)
tab ag3a_10, gen(landtype)
tab ag3a_11, gen(landqlty)
foreach v of var land* {
	replace `v' = `v'*area
	}

save ag_longseason.dta, replace
clear all

*CONTINUE with plots and area from short rainy season
use TZA_LSMS_2014\ag_sec_2b.dta
keep y4_hhid plotnum ag2b_15 ag2b_18 ag2b_20
rename ag2b_15 acres_rprt
rename ag2b_18 measured
rename ag2b_20 acres_msrd
gen acres=acres_rprt	// total acres overseen by household
replace acres=acres_msrd if measured==1

*merge input data for each plot - perfect merge
merge 1:1 y4_hhid plotnum using TZA_LSMS_2014\ag_sec_3b.dta

*land variables for cultivated plots, which are 92% of all plots in sample.
gen area=acres_rprt if ag3b_03==1	// total area under cultivation
replace area=acres_msrd if measured==1 & ag3b_03==1
gen area_rprt=acres_rprt if ag3b_03==1
gen area_msrd=acres_msrd if ag3b_03==1

*limiting sample to maize and rice plots (staples)
gen allcrops=1
gen staples=1 if ag3b_07_1=="MAHINDI"|ag3b_07_1=="MPUNGA" // Maize & Rice
replace staples=0 if staples==. & ag3b_07_1!=""
keep if `dataset'==1

*household labor (in days)
egen labor_hh_prep = rowtotal(ag3b_72_1 ag3b_72_2 ag3b_72_3 ag3b_72_4 ag3b_72_5 ag3b_72_6)
egen labor_hh_mid = rowtotal(ag3b_72_7 ag3b_72_8 ag3b_72_9 ag3b_72_10 ag3b_72_11 ag3b_72_12)
gen labor_hh_preh = labor_hh_prep + labor_hh_mid
egen labor_hh_harv = rowtotal(ag3b_72_13 ag3b_72_14 ag3b_72_15 ag3b_72_16 ag3b_72_17 ag3b_72_18)
gen labor_hh_ttl = labor_hh_preh + labor_hh_harv

*hired labor (in days)
egen labor_wrk_prep = rowtotal(ag3b_74_1 ag3b_74_2 ag3b_74_3)
egen labor_wrk_mid = rowtotal(ag3b_74_5 ag3b_74_6 ag3b_74_7)
gen labor_wrk_preh = labor_wrk_prep + labor_wrk_mid
egen labor_wrk_harv = rowtotal(ag3b_74_13 ag3b_74_14 ag3b_74_15)
gen labor_wrk_ttl = labor_wrk_preh + labor_wrk_harv
rename ag3b_74_4 ttlpaid_prep
rename ag3b_74_8 ttlpaid_mid
gen ttlpaid_preh = ttlpaid_prep + ttlpaid_mid
rename ag3b_74_16 ttlpaid_harv
gen ttlpaid_ttl = ttlpaid_prep + ttlpaid_mid + ttlpaid_harv

*aggregate labor (in days)
gen labor_preh = labor_hh_preh + labor_wrk_preh
gen labor_harv = labor_hh_harv + labor_wrk_harv
gen labor_ttl = labor_hh_ttl + labor_wrk_ttl

*inputs
gen fert_value = ag3b_51+ag3b_51 
gen fert_qty = ag3b_49+ag3b_56 
gen pest_value = ag3b_65c
gen pest_qty = ag3b_65b_1 if ag3b_65b_2==2	// in litres
replace pest_qty = ag3b_65b_1/1000 if ag3b_65b_2==3	// putting ml in same units

*irrigation: 98% of plots were not irrigated in the long rainy season, so I'm excluding this from regressors

*land quality--multiply by cultivated area to collapse
recode ag3b_17 (1=1 "flat") (2=1 "flat")(3=2 "slight") (4=3 "steep"), gen(landslope)  // land slope
tab landslope, gen(landslope)
tab ag3b_10, gen(landtype)
tab ag3b_11, gen(landqlty)
foreach v of var land* {
	replace `v' = `v'*area
	}

save ag_shortseason.dta, replace
append using ag_longseason.dta

*collapse to hh level
collapse (sum) acres* area* labor* ttlpaid* fert* pest* land*, by(y4_hhid)

*wages - total paid divided by days worked
gen wage_preh = ttlpaid_preh / labor_wrk_preh
gen wage_harv = ttlpaid_harv / labor_wrk_harv
gen wage_ttl = ttlpaid_ttl / labor_wrk_ttl
foreach x in preh harv ttl {
	gen wagedummy_`x'=1 
replace wagedummy_`x'=0 if wage_`x'==.
}
summarize wagedummy*

*input price--unfotunately, less than 10% use either fert or pest, so I will not include in regression
gen fert_dummy=1 if fert_qty>0
replace fert_dummy=0 if fert_qty==0
gen pest_dummy=1 if pest_qty>0
replace pest_dummy=0 if pest_qty==0
summarize fert_dummy pest_dummy
gen fert_price = fert_value / fert_qty // total value divided by qty used
gen pest_price = pest_value / pest_qty

*land quality--divide by area to get share of land with said characteristic
label var acres "total land overseen by hh"
label var area "total cultivated land"
foreach v of var land* {
	replace `v' = `v'/area
	}
label var landslope1 "% flat land"
label var landslope2 "% slight land"
label var landslope3 "% steep land"
label var landtype1 "% sandy land"
label var landtype2 "% loam land"
label var landtype3 "% clay land"
label var landtype4 "% other land"
label var landqlty1 "% good land"
label var landqlty2 "% avg land"
label var landqlty3 "% bad land"
	
*variable log transformations
gen lnlabor_preh = log(labor_preh + 0.01)
gen lnlabor_harv = log(labor_harv + 0.01)
gen lnlabor_ttl = log(labor_ttl + 0.01)
gen lnarea_rprt = log(acres_rprt + 0.01)
gen lnarea_msrd = log(acres_msrd + 0.01)
gen lnarea = log(area + 0.01)
foreach v of var wage* pest_price fert_price {
	gen ln`v' = log(`v' + 0.01)
}
	
save agdata.dta, replace 

**PART 3: Merge Datasets
merge 1:1 y4_hhid using hhdata.dta
keep if _merge==3	// drop hh without ag production
drop _merge
merge 1:1 y4_hhid using TZA_LSMS_2014\hh_sec_a.dta
keep if _merge==3	// drop hh without ag production
drop _merge
*strataid has rural and urban households in each region (min 16 and max 552)
*cluserid puts every household with 7 other hhs in a cluster
*clustertype defines each household cluster as rural or urban
rename hh_a01_1 regioncode
rename hh_a01_2 region
rename hh_a02_1 districtcode
rename hh_a02_2 district
rename hh_a03_1 wardcode
rename hh_a03_3a villagecode 
drop occ hh_a06 hh_a13 y4_rural wardtype hh_a*
*Number of household in clusterid where lnwage_preh!=.
sort clusterid
gen cluster_dummy = 1 if clusterid==clusterid[_n-1] & lnwage_preh!=.
	replace cluster_dummy = 1 if clusterid==clusterid[_n+1] & lnwage_preh!=.
	egen cluster_count = total(cluster_dummy), by(clusterid) //# of hhs in cluster
	tab cluster_count
*average preharv wage by cluster
egen wage_preh_avg = mean(wage_preh), by(clusterid)
gen lnwage_preh_avg = log(wage_preh_avg + 0.01)
egen wage_harv_avg = mean(wage_harv), by(clusterid)
gen lnwage_harv_avg = log(wage_harv_avg + 0.01)
egen districtid = group(regioncode districtcode) 

**PART 4: Geographic Variables
*City dummies:
*dar es salaam
recode domain (1=1) (2=0) (3=0) (4=0), gen(daressalaam)
gen daressalaam_peri=1 if district=="BAGAMOYO"|district=="KIBAHA MJI"| ///
district=="KISARAWE"|district=="MKURANGA"| ///
district=="KIBAHA"
gen daressalaam_area=1 if daressalaam==1|daressalaam_peri==1
*mwanza
gen mwanza=1 if district=="ILEMELA MANISPAA"|district=="NYAMAGANA MANISPAA"
gen mwanza_peri=1 if district=="MAGU"|district=="MISUNGWI"| ///
district=="SENGEREMA"
gen mwanza_area=1 if mwanza==1|mwanza_peri==1
*arusha
gen arusha=1 if district=="ARUSHA MJINI"
gen arusha_peri=1 if district=="ARUSHA"|district=="MERU"| ///
district=="MONDULI"|district=="SIMANJIRO"
gen arusha_area=1 if arusha==1|arusha_peri==1
*dodoma
gen dodoma=1 if district=="DODOMA MJINI"
gen dodoma_peri=1 if district=="BAHI"|district=="CHAMWINO"
gen dodoma_area=1 if dodoma==1|dodoma_peri==1
*mbeya
gen mbeya=1 if district=="MBEYA JIJI"
gen mbeya_peri=1 if district=="MBARALI"|district=="MBEYA"| ///
district=="RUNGWE"
gen mbeya_area=1 if mbeya==1|mbeya_peri==1
*missing values encode
mvencode daressalaam_* mwanza* arusha* dodoma* mbeya*, mv(0)
*aggregate variables
gen topcity=daressalaam+mwanza+arusha+dodoma+mbeya
gen peritopcity=daressalaam_peri+mwanza_peri+arusha_peri+dodoma_peri+mbeya_peri
*Summary categorical variable for Top Cities:
gen citycat=0
replace citycat=1 if peritopcity==1
replace citycat=2 if topcity==1

*Urban Cluster dummy
recode clustertype (1=0 rural) (2=1 urban), gen(urbancluster)
egen urbanpct = mean(urbancluster), by(district)
*Peri-Urban Cluster District dummy:
gen periurban=0
	*part of a semi-urban district:
replace periurban=1 if urbanpct<1 & urbanpct>0 & urbancluster==0
	*neighboring a fully urban district:
replace periurban=1 if district=="ARUSHA"|district=="BABATI"|district=="BAGAMOYO"|  ///
district=="BUKOBA"|district=="HAI"|district=="IKUNGI"|district=="IRINGA"|  ///
district=="KALAMBO"|district=="KIBAHA"|district=="KIBAHA MJI"|district=="KIGMOA"| ///
district=="KILOLO"|district=="KISARAWE"|district=="LINDI"|district=="LUDEWA"| ///
district=="MAGU"|district=="MAKETE"|district=="MBARALI"|district=="MBEYA"| ///
district=="MERU"|district=="MISUNGWI"|district=="MKINGA"|district=="MKURANGA"| ///
district=="MLELE"|district=="MOROGORO"|district=="MOSHI"|district=="MPANDA"| ///
district=="MTWARA VIJIJINI"|district=="MUFINDI"|district=="MUHEZA"|district=="MVOMERO"| ///
district=="NAMTUMBO"|district=="NJOMBE"|district=="NKASI"|district=="NZEGA"| ///
district=="SINGIDA"|district=="SONGEA"|district=="SUMBAWANGA"|district=="UVINZA"| ///
district=="UYUI"|district=="WANG'ING'OMBE"
	*less than 10km away from a fully urban district: 
replace periurban=1 if district=="HANANG"|district=="KONDOA"|district=="MISSENYI"| ///
district=="MONDULI"|district=="PANGANI"|district=="RORYA"|district=="RUNGWE"| ///
district=="SENGEREMA"|district=="SIKONGE"|district=="SIMANJIRO" 
*In case urban districts are neighboring, labeling an urban cluster as periurban
replace periurban=0 if urbancluster==1
*Summary categorical variable for Urban Cluster:
gen clustercat=0
replace clustercat=1 if periurban==1
replace clustercat=2 if urbancluster==1

*Zanzibar dummy: used to separate zanzibar from urban peri-urban analysis
recode domain (1=0) (2=0) (3=0) (4=1), gen(zanzibar_area)
replace citycat=3 if zanzibar_area==1
replace clustercat=3 if zanzibar_area==1

*Label for categorical variables
label define labelcat 0 "rural" 1 "periurban" 2 "urban" 3 "zanzibar"
label values citycat clustercat labelcat

*Save dataset:
save data_`dataset'.dta, replace
}

Note: Setup complete. Select and execute remaining code to replicate the results.


****************
* MAIN RESULTS *
****************
*Code reproduces results for each table in consecutive order
*Select and execute code beneath a table heading to produce its results

**Table 1: Sample Descriptives
clear all
use data_allcrops
gen ag = area>0 
sum ag [weight=y4_weights]
sum ag 
gen famlabor = labor_hh_ttl>0 if ag==1 
gen hiredlabor_preh = labor_wrk_preh>0 if ag==1 
gen hiredlabor_harv = labor_wrk_harv>0 if ag==1 
gen hiredlabor_ttl = labor_wrk_ttl>0 if ag==1 
sum labor_preh labor_hh_preh labor_wrk_preh hiredlabor_preh labor_harv labor_hh_harv labor_wrk_harv ///
hiredlabor_harv labor_ttl labor_hh_ttl labor_wrk_ttl hiredlabor_ttl if ag==1 [weight=y4_weights], sep(4)
*to get percent of landed hh that grow maize or rice
merge 1:1 y4_hhid using data_staples.dta
gen staples = _merge==3
sum staples [weight=y4_weights]
sum staples 
sum staples if ag==1 [weight=y4_weights]
sum staples if ag==1 

**Table 2: Top Five Cities
foreach dataset in allcrops staples {
clear all
use data_`dataset'
keep if area>0
qui reg lnlabor_preh lnwage_preh_avg lnarea lnhhsize [pweight=y4_weights], vce(cluster clusterid)
foreach r of varlist daressalaam daressalaam_peri mwanza mwanza_peri arusha arusha_peri dodoma ///
dodoma_peri mbeya mbeya_peri {
qui sum `r' if `r'==1 & e(sample)==1 [weight=y4_weights]
estadd scalar N_`r' = r(N)
}
}

**Table 3: Summary Stats
foreach dataset in allcrops staples {
clear all
use data_`dataset'
keep if area>0
qui reg lnlabor_preh lnwage_preh_avg lnarea lnhhsize [pweight=y4_weights], vce(cluster clusterid)
sum labor_preh wage_preh_avg area hhsize i.clustercat i.citycat ///
daressalaam_area mwanza_area arusha_area dodoma_area mbeya_area zanzibar_area ///
if e(sample)==1 [weight=y4_weights], sep(0)
}

**Analysis: Regressions on Demand for Pre-Harvest Labor
*Must run before replicating Tables 4 & 5
clear all
foreach d in allcrops staples {
use data_`d'.dta
keep if area>0
local indepvar "lnwage_preh_avg lnarea lnhhsize"
*Baseline Specification
qui reg lnlabor_preh `indepvar' [pweight=y4_weights], vce(cluster clusterid)
	estadd ysumm
	estimates store preh_`d'_1
*Specficiation 1: Urban Sampling Clusters
qui reg lnlabor_preh `indepvar' i.clustercat c.lnhhsize#i.clustercat ///
[pweight=y4_weights], vce(cluster clusterid)
	*test significance of beta plus interaction term, and store sub-sample size
	foreach n of numlist 1/3 {
	estadd scalar B_`n' = _b[lnhhsize] + _b[c.lnhhsize#`n'.clustercat]
	qui test c.lnhhsize+c.lnhhsize#`n'.clustercat=0
	estadd scalar F_`n' = r(F)
	estadd scalar p_`n' = r(p)
	qui sum clustercat if clustercat==`n'
	estadd scalar N_`n' = r(N)
	}
	*test that hh remains jointly significant across interactions
	qui testparm c.lnhhsize c.lnhhsize#i(1/3).clustercat
	estadd scalar F_hh = r(F)
	estadd scalar p_hh = r(p)
	*store results
	estimates store preh_`d'_2
*Specification 2: Top Five Urban Centers, Aggregated
qui reg lnlabor_preh `indepvar' i.citycat c.lnhhsize#i.citycat ///
[pweight=y4_weights], vce(cluster clusterid)
	*test significance of beta plus interaction term, and store sub-sample size
	foreach n of numlist 1/3 {
	estadd scalar B_`n' = _b[lnhhsize] + _b[c.lnhhsize#`n'.citycat]
	qui test c.lnhhsize+c.lnhhsize#`n'.citycat=0
	estadd scalar F_`n' = r(F)
	estadd scalar p_`n' = r(p)
	qui sum citycat if citycat==`n'
	estadd scalar N_`n' = r(N)
	}
	*test that hh remains jointly significant across interactions
	qui testparm c.lnhhsize c.lnhhsize#i(1/3).citycat
	estadd scalar F_hh = r(F)
	estadd scalar p_hh = r(p)
	*store results
	estimates store preh_`d'_3
*Specification 3: Top Five Urban Centers, Disaggregated 
qui reg lnlabor_preh `indepvar' daressalaam_area c.lnhhsize#daressalaam_area ///
mwanza_area c.lnhhsize#mwanza_area arusha_area c.lnhhsize#arusha_area ///
dodoma_area c.lnhhsize#dodoma_area mbeya_area c.lnhhsize#mbeya_area ///
zanzibar_area c.lnhhsize#zanzibar_area [pweight=y4_weights], vce(cluster clusterid)
	*test significance of beta plus interaction term, and store sub-sample size
	foreach r in daressalaam mwanza arusha dodoma mbeya zanzibar {
	estadd scalar B_`r' = _b[lnhhsize] + _b[c.lnhhsize#1.`r'_area]
	qui test c.lnhhsize+c.lnhhsize#1.`r'_area=0
	estadd scalar F_`r' = r(F)
	estadd scalar p_`r' = r(p)
	qui sum `r'_area if `r'_area==1
	estadd scalar N_`r' = r(N)
	}
	*test that hh remains jointly significant across interactions
	qui testparm c.lnhhsize c.lnhhsize#daressalaam_area c.lnhhsize#mwanza_area ///
	c.lnhhsize#arusha_area c.lnhhsize#dodoma_area c.lnhhsize#mbeya_area c.lnhhsize#zanzibar_area
	estadd scalar F_hh = r(F)
	estadd scalar p_hh = r(p)
	*store results
	estimates store preh_`d'_4
	clear
}


**Table 4: Separability Results for Specifications (1) (2) and (3) w/ added stats
*For clustercat and citycat: 0 is rural (baseline), 1 is peri-urban, 2 is urban, 3 is zanzibar
estout preh_allcrops_1 preh_allcrops_2 preh_allcrops_3 preh_staples_1 preh_staples_2 preh_staples_3, ///
cells(b(star fmt(4)) se(fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(r2 N F_hh p_hh B_1 p_1 N_1 B_2 p_2 N_2 B_3 p_3 N_3)

**Table 5: Separability Results for Specification (4) w/ added stats
estout preh_allcrops_4 preh_staples_4, ///
cells(b(star fmt(4)) se(fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(r2 N F_hh p_hh N_daressalaam B_daressalaam p_daressalaam F_daressalaam ///
N_mwanza B_mwanza p_mwanza F_mwanza ///
N_arusha B_arusha p_arusha F_arusha ///
N_dodoma B_dodoma p_dodoma F_dodoma ///
N_mbeya B_mbeya p_mbeya F_mbeya ///
N_zanzibar B_zanzibar p_zanzibar F_zanzibar) 


********************
* APPENDIX RESULTS *
********************
*Full specification of labor demand function using other regressors seen in the literature, including...
*Hh Composition: fraction of prime-age men, prime-age women, and elder women (excludes elder men as baseline)
*Hh Head Attributes: age, age squared, indicator if literate, indicator if had any formal schooling
*Land Attributes (Hh-reported): slope (slight or steep, vs flat), type (sand or clay, vs loam) & quality (good or bad, vs average)

*Table A1: Specification with Region Dummies and Interactions
clear all
use data_allcrops
keep if area>0
qui reg lnlabor_preh lnwage_preh_avg lnarea lnhhsize i.regioncode c.lnhhsize#i.regioncode ///
[pweight=y4_weights], vce(cluster clusterid)
	estimates store preh_allcrops_region
estout preh_allcrops_region, cells("b(star fmt(4)) se(fmt(4))") ///
style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(r2 N)

**Table A2: Summary Stats for Full Specification
foreach dataset in allcrops staples {
clear all
use data_`dataset'
keep if area>0
local indepvar "lnwage_preh_avg lnarea lnhhsize frac_mprime frac_fprime frac_felder age_head c.age_head#c.age_head literate_head anyschool_head landslope2 landslope3 landtype1 landtype3 landqlty1 landqlty3"
qui reg `indepvar' [pweight=y4_weights], vce(cluster clusterid)
sum labor_preh wage_preh_avg area hhsize frac_mprime frac_fprime frac_melder frac_felder ///
age_head c.age_head#c.age_head literate_head anyschool_head ///
landslope2 landslope3 landtype1 landtype3 landqlty1 landqlty3 i.clustercat i.citycat ///
daressalaam_area mwanza_area arusha_area dodoma_area mbeya_area zanzibar_area ///
if e(sample)==1 [weight=y4_weights], sep(0)
}

**Analysis: Regressions on Demand for Pre-Harvest Labor with Full Specification
*Must run before replicating Tables A3 & A4
clear all
foreach d in allcrops staples {
use data_`d'.dta
keep if area>0
local indepvar "lnwage_preh_avg lnarea lnhhsize frac_mprime frac_fprime frac_felder age_head c.age_head#c.age_head literate_head anyschool_head landslope2 landslope3 landtype1 landtype3 landqlty1 landqlty3"
*Baseline Specification
qui reg lnlabor_preh `indepvar' [pweight=y4_weights], vce(cluster clusterid)
	estadd ysumm
	estimates store preh_`d'_1
*Specficiation 1: Urban Sampling Clusters
qui reg lnlabor_preh `indepvar' i.clustercat c.lnhhsize#i.clustercat ///
[pweight=y4_weights], vce(cluster clusterid)
	*test significance of beta plus interaction term, and store sub-sample size
	foreach n of numlist 1/3 {
	estadd scalar B_`n' = _b[lnhhsize] + _b[c.lnhhsize#`n'.clustercat]
	qui test c.lnhhsize+c.lnhhsize#`n'.clustercat=0
	estadd scalar F_`n' = r(F)
	estadd scalar p_`n' = r(p)
	qui sum clustercat if clustercat==`n'
	estadd scalar N_`n' = r(N)
	}
	*test that hh remains jointly significant across interactions
	qui testparm c.lnhhsize c.lnhhsize#i(1/3).clustercat
	estadd scalar F_hh = r(F)
	estadd scalar p_hh = r(p)
	*store results
	estimates store preh_`d'_2
*Specification 2: Top Five Urban Centers, Aggregated
qui reg lnlabor_preh `indepvar' i.citycat c.lnhhsize#i.citycat ///
[pweight=y4_weights], vce(cluster clusterid)
	*test significance of beta plus interaction term, and store sub-sample size
	foreach n of numlist 1/3 {
	estadd scalar B_`n' = _b[lnhhsize] + _b[c.lnhhsize#`n'.citycat]
	qui test c.lnhhsize+c.lnhhsize#`n'.citycat=0
	estadd scalar F_`n' = r(F)
	estadd scalar p_`n' = r(p)
	qui sum citycat if citycat==`n'
	estadd scalar N_`n' = r(N)
	}
	*test that hh remains jointly significant across interactions
	qui testparm c.lnhhsize c.lnhhsize#i(1/3).citycat
	estadd scalar F_hh = r(F)
	estadd scalar p_hh = r(p)
	*store results
	estimates store preh_`d'_3
*Specification 3: Top Five Urban Centers, Disaggregated 
qui reg lnlabor_preh `indepvar' daressalaam_area c.lnhhsize#daressalaam_area ///
mwanza_area c.lnhhsize#mwanza_area arusha_area c.lnhhsize#arusha_area ///
dodoma_area c.lnhhsize#dodoma_area mbeya_area c.lnhhsize#mbeya_area ///
zanzibar_area c.lnhhsize#zanzibar_area [pweight=y4_weights], vce(cluster clusterid)
	*test significance of beta plus interaction term, and store sub-sample size
	foreach r in daressalaam mwanza arusha dodoma mbeya zanzibar {
	estadd scalar B_`r' = _b[lnhhsize] + _b[c.lnhhsize#1.`r'_area]
	qui test c.lnhhsize+c.lnhhsize#1.`r'_area=0
	estadd scalar F_`r' = r(F)
	estadd scalar p_`r' = r(p)
	qui sum `r'_area if `r'_area==1
	estadd scalar N_`r' = r(N)
	}
	*test that hh remains jointly significant across interactions
	qui testparm c.lnhhsize c.lnhhsize#daressalaam_area c.lnhhsize#mwanza_area ///
	c.lnhhsize#arusha_area c.lnhhsize#dodoma_area c.lnhhsize#mbeya_area c.lnhhsize#zanzibar_area
	estadd scalar F_hh = r(F)
	estadd scalar p_hh = r(p)
	*store results
	estimates store preh_`d'_4
	clear
}
**Table A3: Separability Results for Full Specifications (1) (2) and (3) w/ added stats
*For clustercat and citycat: 0 is rural (baseline), 1 is peri-urban, 2 is urban, 3 is zanzibar
estout preh_allcrops_1 preh_allcrops_2 preh_allcrops_3 preh_staples_1 preh_staples_2 preh_staples_3, ///
cells(b(star fmt(4)) se(fmt(4)) p) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(r2 N F_hh p_hh B_1 p_1 N_1 B_2 p_2 N_2 B_3 p_3 N_3)

**Table A4: Separability Results for Full Specification (4) w/ added stats
estout preh_allcrops_4 preh_staples_4, ///
cells(b(star fmt(4)) se(fmt(4))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(r2 N F_hh p_hh N_daressalaam B_daressalaam p_daressalaam F_daressalaam ///
N_mwanza B_mwanza p_mwanza F_mwanza ///
N_arusha B_arusha p_arusha F_arusha ///
N_dodoma B_dodoma p_dodoma F_dodoma ///
N_mbeya B_mbeya p_mbeya F_mbeya ///
N_zanzibar B_zanzibar p_zanzibar F_zanzibar) 

